(function() {
  var Issue, IssueController, IssuePanelView, IssueView, Issues, IssuesView, NewIssueView;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };

  IssueController = (function() {

    __extends(IssueController, Backbone.Router);

    function IssueController() {
      IssueController.__super__.constructor.apply(this, arguments);
    }

    IssueController.prototype.routes = {
      "issues": "issues",
      "issue/:id": "issue",
      "issues/new": "newIssue"
    };

    IssueController.prototype.issues = function() {
      App.Controllers.Issues.renderIssues();
      return $('article').html('<div id="arrow"><img src="images/arrow.png"> Select an issue to view</div>');
    };

    IssueController.prototype.issue = function(id) {
      if (App.Collections.Issues.models.length === 0) {
        return App.Collections.Issues.fetch({
          success: function() {
            App.Controllers.Issues.renderIssues();
            return App.Controllers.Issues.renderPanel(id);
          }
        });
      } else {
        return App.Controllers.Issues.renderPanel(id);
      }
    };

    IssueController.prototype.newIssue = function() {
      var newForm;
      if (App.Collections.Issues.models.length === 0) {
        App.Controllers.Issues.renderIssues();
      }
      newForm = new App.Views.NewIssueView();
      return $('article').html(newForm.render().el);
    };

    IssueController.prototype.renderIssues = function() {
      var issues;
      issues = new App.Views.IssuesView({
        collection: App.Collections.Issues
      });
      return $('#issues').html(issues.render().el);
    };

    IssueController.prototype.renderPanel = function(id) {
      var view;
      view = new App.Views.IssuePanelView({
        model: App.Collections.Issues.get(id)
      });
      $('article').html(view.render().el);
      return view.after_render();
    };

    return IssueController;

  })();

  App.Controllers.Issues = new IssueController;

  Issue = (function() {

    __extends(Issue, Backbone.Model);

    function Issue() {
      Issue.__super__.constructor.apply(this, arguments);
    }

    Issue.prototype.defaults = {};

    Issue.prototype.name = 'issue';

    Issue.prototype.url = function() {
      return "https://api.github.com/repos/dmix/backbone-github-issues/issues" + App.Functions.auth_token();
    };

    return Issue;

  })();

  App.Models.Issue = Issue;

  Issues = (function() {

    __extends(Issues, Backbone.Collection);

    function Issues() {
      Issues.__super__.constructor.apply(this, arguments);
    }

    Issues.prototype.model = App.Models.Issue;

    Issues.prototype.url = function() {
      return "https://api.github.com/repos/dmix/backbone-github-issues/issues" + App.Functions.auth_token();
    };

    return Issues;

  })();

  App.Collections.Issues = new Issues;

  IssueView = (function() {

    __extends(IssueView, Backbone.View);

    function IssueView() {
      IssueView.__super__.constructor.apply(this, arguments);
    }

    IssueView.prototype.initialize = function() {
      _.bindAll(this, 'render');
      this.model.bind('change', this.render);
      return this.template = ich.issue;
    };

    IssueView.prototype.render = function() {
      var content;
      content = this.template(this.model.toJSON());
      $(this.el).html(content);
      return this;
    };

    return IssueView;

  })();

  App.Views.IssueView = IssueView;

  IssuePanelView = (function() {

    __extends(IssuePanelView, Backbone.View);

    function IssuePanelView() {
      IssuePanelView.__super__.constructor.apply(this, arguments);
    }

    IssuePanelView.prototype.initialize = function() {
      _.bindAll(this, 'render');
      this.model.bind('change', this.render);
      return this.template = ich.issuePanel;
    };

    IssuePanelView.prototype.render = function() {
      var content;
      content = this.template(this.model.toJSON());
      $(this.el).html(content);
      return this;
    };

    IssuePanelView.prototype.after_render = function() {
      var attrs, issue_id, markdown;
      attrs = this.model.toJSON();
      markdown = new Markdown.Converter();
      $('#body_html').html(markdown.makeHtml(attrs.body));
      issue_id = '#issue_' + attrs.id;
      $('#issues .active').removeClass('active');
      return $(issue_id).addClass('active');
    };

    return IssuePanelView;

  })();

  App.Views.IssuePanelView = IssuePanelView;

  IssuesView = (function() {

    __extends(IssuesView, Backbone.View);

    function IssuesView() {
      IssuesView.__super__.constructor.apply(this, arguments);
    }

    IssuesView.prototype.initialize = function() {
      _.bindAll(this, 'render');
      this.template = ich.issues;
      if (App.Collections.Issues.models.length === 0) this.collection.fetch();
      this.collection.bind('reset', this.render);
      return this.collection.bind('add', this.render);
    };

    IssuesView.prototype.render = function() {
      var collection, issue_id, issues_html;
      collection = this.collection;
      issues_html = "";
      collection.each(function(issue) {
        var view;
        view = new IssueView({
          model: issue
        });
        return issues_html += view.render().el.innerHTML;
      });
      $(this.el).html(issues_html);
      if ($('#active_issue')) {
        issue_id = '#issue_' + $('#active_issue').val();
        $('#issues .active').removeClass('active');
        $(issue_id).addClass('active');
      }
      return this;
    };

    return IssuesView;

  })();

  App.Views.IssuesView = IssuesView;

  NewIssueView = (function() {

    __extends(NewIssueView, Backbone.View);

    function NewIssueView() {
      NewIssueView.__super__.constructor.apply(this, arguments);
    }

    NewIssueView.prototype.events = {
      "click #createIssue": "createIssue"
    };

    NewIssueView.prototype.render = function() {
      $(this.el).html(ich.newIssue());
      return this;
    };

    NewIssueView.prototype.createIssue = function(e) {
      var body, issue, title;
      title = this.$("input[name='title']").val();
      body = this.$("textarea[name='body']").val();
      $("button").hide();
      issue = new App.Models.Issue();
      return issue.save({
        title: title,
        body: body
      }, {
        success: function(model, resp) {
          App.Collections.Issues.fetch({
            success: function() {
              var view;
              view = new App.Views.IssuePanelView({
                model: App.Collections.Issues.getByCid(issue.cid)
              });
              $('article').html(view.render().el);
              return view.after_render();
            }
          });
          return alert("Issue created successfully.");
        },
        error: function(request, error) {
          var error_text;
          error_text = "Failed to Create issue: " + request.responseText;
          alert(error_text);
          return $("button").show();
        }
      });
    };

    return NewIssueView;

  })();

  App.Views.NewIssueView = NewIssueView;

}).call(this);
