class OAuthController extends Backbone.Router
  routes: {
    "oauth" : "oauth"
  },

  oauth: ->
    # Open modal explaining that the app is retrieving github account details
    $('#OAuthModal').modal({ backdrop: true, show: true })
    # Retrieve user account details from github using auth_token returned by github
    auth_token = App.Functions.getUrlParameter("auth_token")
    App.Functions.storeToken(auth_token)
    App.Functions.retrieveUser(auth_token)

App.Controllers.OAuth = new OAuthController

class UserView extends Backbone.View
  initialize: ->
    @template = ich.user

  render: ->
    # Show logged in github user's login and avatar at the top right of page
    $(@el).html(@template(App.Models.User))
    return this

App.Views.UserView = UserView

App.Functions.retrieveUser = (auth_token) ->
  $.ajax({
    type: 'GET',
    url: 'https://api.github.com/user?access_token=' + auth_token,
    success: (data) ->
      # Store github user information in localstorage
      App.Functions.storeUser(data)
      # Hide github modal
      $('#OAuthModal').modal('hide')
      window.location = "/index.html"
    error : (request,error) ->
      alert("Failed to retrieve user: " + request.responseText)
  })

App.Functions.storeToken = (auth_token) ->
  localStorage.setItem('auth_token', auth_token)

App.Functions.storeUser = (user) ->
  localStorage.setItem('login', user.login)
  localStorage.setItem('avatar_url', user.avatar_url)
  localStorage.setItem('url', user.html_url)
  localStorage.setItem('name', user.name)

App.Functions.logOut = ->
  localStorage.clear()
  $('#userView').html('<a href="http://dmix.ca/auth/github" class="btn ">Login with Github</a>')
  alert("Logged out")

App.Functions.logIn = ->
  if localStorage.getItem('auth_token') != null
    App.Functions.loadUser()
    return true

App.Functions.loadUser = ->
  if localStorage.getItem('auth_token') != null
    App.Models.User = {
      login: localStorage.getItem('login'),
      avatar_url: localStorage.getItem('avatar_url'),
      url: localStorage.getItem('url'),
      name: localStorage.getItem('name'),
      auth_token: localStorage.getItem('auth_token')
    }
    # Render user information on the top right of page if auth_token exists
    view = new App.Views.UserView()
    $('#userView').html(view.render().el)

App.Functions.auth_token = ->
  token = if localStorage.getItem('auth_token')
    localStorage.getItem('auth_token')
  else
    ""
  "?access_token=" + token